% Burgers, Up-Wind conservativo y no conservativo. 

nx=100;
x=linspace(0,50,nx);
dx = x(2)-x(1);

nu = 1/5;
dt = nu*dx;

% Elección del dato inicial, y Tf: 
opcion = 2;

switch opcion
    
    case 1
         % Dato suave con u_x que deja de existir.
        init = @(x) exp(-x)./(1+exp(-x));    
        Tf = 1000;
        
    case 2
        % No-Conservativo no hace nada
        init = @(x) (x<10);  
        Tf = 80;
        
    case 3
        % Conservativo y No-Conservativo se mueve a distinta velocidad
        init = @(x) (x<10)*0.8 + 0.2;      
        Tf = 80;
end

% Inicialización de memoria
nt = Tf/dt;
u = zeros(nt,nx);
w = zeros(nt,nx);

u(1,:) = init(x);
w(1,:) = init(x);

% Limites de los ejes
v = [0,x(end),min(init(x)),max(init(x))];

for n=2:nt
    ii = 2:nx; 
    
    % Conservativo
    u(n,ii) = u(n-1,ii) - dt/dx * ( u(n-1,ii).^2/2 - u(n-1,ii-1).^2/2 );
    u(n,1) = init(x(1));
    
    % NO-Conservativo
    w(n,ii) = w(n-1,ii) - dt/dx * w(n-1,ii).*( w(n-1,ii) - w(n-1,ii-1) );
    w(n,1) = init(x(1));

    % Titulos de plots
    str1 = ['Burgers con Up-Wind Conservativo, t=', num2str(n*dt,'%1.2f')];
    str2 = ['Burgers con Up-Wind NO-Conservativo, t=', num2str(n*dt,'%1.2f')];
    
    subplot(2,1,1);
    plot(x,u(n,:),'*'); axis(v); title(str1,'FontSize',20)

    subplot(2,1,2);
    plot(x,w(n,:),'*'); axis(v); title(str2,'FontSize',20)
    
    drawnow;
end

